      program deaccumulate
********************************************************************
*                                                                  *
*                     Author: G. WOTAWA                            *
*                     1994-06-03                                   *
*                                                                  *
********************************************************************
*                                                                  *
* DESCRIPTION: This program reads accumulated values of            *
*                                                                  *
*     large scale precipitation                                    *
*     convective precipitation                                     *
*     surface sensible heat flux                                   *
*     surface solar radiation                                      *
*     u stress                                                     *
*     v stress                                                     *
*                                                                  *
* Afterwards, accumulated quantities are deaccumulated,            *
* interpolated to 00/03/06/09/12/15/18/21 and written to output    *
* files                                                            *
*                                                                  *
********************************************************************

      include 'parameter'
      include 'commonvar'

      integer it,i,j
      integer idate(maxtime),itges
      real step,steprain
*
* READ FLUXES FROM INPUT DATA FILES
*
      call readflux(idate,itges)
      if(itges.lt.3) 
     &   stop 'SORRY: TIME NOT SUFFICIENT FOR INTERPOLATION'
*
* DEACCUMULATE ACCUMULATED FLUXES
*
* LSP,CP:     [mm/hr]
* SSR, SSHF:  [W/(m*m)]
* EWSS, NSSS: [N/(m*m)]
*
      step=3600.*3.
      steprain=3.
      do 100 it=itges,1,-1
         if(mod(it,2).eq.1) then
            do 25 i=1,nx
               do 25 j=1,ny
                  lsp (i,j,it) = lsp (i,j,it)/steprain * 1000.
                  cp  (i,j,it) = cp  (i,j,it)/steprain * 1000.
                  sshf(i,j,it) = sshf(i,j,it)/step
                  ssr (i,j,it) = ssr (i,j,it)/step
                  ewss(i,j,it) = ewss(i,j,it)/step
25                nsss(i,j,it) = nsss(i,j,it)/step
      else
            do 75 i=1,nx
               do 75 j=1,ny
                  lsp (i,j,it) = (lsp (i,j,it) - lsp (i,j,it-1))
     &                         / steprain * 1000.
                  cp  (i,j,it) = (cp  (i,j,it) - cp  (i,j,it-1))
     &                         / steprain * 1000.
                  sshf(i,j,it) = (sshf(i,j,it) - sshf(i,j,it-1))
     &                         / step
                  ssr (i,j,it) = (ssr(i,j,it)  - ssr (i,j,it-1))
     &                         / step
                  ewss(i,j,it) = (ewss(i,j,it) - ewss(i,j,it-1))
     &                         / step
75                nsss(i,j,it) = (nsss(i,j,it) - nsss(i,j,it-1))
     &                         / step
      endif
100   continue
*
* INTERPOLATE FLUXES TO GIVEN TIMES
*
      call fluxinterpol(itges)
*
* WRITE TO OUTPUT FILES
*
      call writeout(idate,itges)

      end
