      subroutine readflux(idate,itges)
********************************************************************
*                                                                  *
*                     Author: G. WOTAWA                            *
*                     1994-06-03                                   *
*                                                                  *
********************************************************************
*                                                                  *
* DESCRIPTION: This program reads accumulated values of            *
*                                                                  *
*     QUANTITY                     MARS ABBR    CODE               *
*                                                                  *
*     large scale precipitation       LSP       142                *
*     convective precipitation        CP        143                *
*     surface sensible heat flux      SSHF      146                *
*     surface solar radiation         SSR       176                *
*     u stress                        EWSS      180                *
*     v stress                        NSSS      181                * 
*                                                                  *
*              from the following input files:                     *
*                                                                  *
*              surf_06_ub: first guess surface data 00/06/12/18    *
*              surf_03_ub: first guess surface data 03/09/15/21    *
*                                                                  *
* All input data files have to be unblocked grib code.             *
*                                                                  *
********************************************************************
      include 'parameter'
      include 'commonvar'

      integer kunit1,kunit2,ierr,lenght,iword,i,j,itime
      integer idate(maxtime),idnum(12),itges
      integer ij,im,id,ih,idel,ind,ic,jmd,hms
      integer INBUFF(IDIMENS*4)
      integer ISEC0(2),ISEC1(56),ISEC2(384),ISEC3(2),ISEC4(42)
      real ZSEC2(96),ZSEC3(2),ZSEC4(IDIMENS)

      character*15 fname1,fname2
      character*1 mode

      double precision jul,juldate

      data fname1 /'/tmp/surf_06_ub'/
      data fname2 /'/tmp/surf_03_ub'/
      data mode /'D'/
      data idnum /31,0,31,30,31,30,31,31,30,31,30,31/
*
      call PBOPEN(kunit1,fname1,'r',ierr)
      if(ierr.lt.0) stop ' SUBROUTINE PBOPEN: ERROR OPENING FILE'
      call PBOPEN(kunit2,fname2,'r',ierr)
      if(ierr.lt.0) stop ' SUBROUTINE PBOPEN: ERROR OPENING FILE'
*
* SKIP FIRST TIME, WHICH IS NOT NECCESSARY
*
      do 5 ind=1,6
5       call PBGRIB(kunit1,INBUFF,IDIMENS*8,lenght,ierr)

      itime=0
10    itime=itime+1

      if(itime.gt.maxtime) then
         write(*,*) 'PLEASE NOTICE: NOT ENOUGH MEMORY TO READ'//
     &              ' ALL FLUXES'
         goto 300
      endif
*
***********************************
* P A R T  I: FG 03/09/15/21      *
* FLUXES ACCUMULATED OVER 3 HOURS *
***********************************
*
      do 100 ind=1,6
        call PBGRIB(kunit2,INBUFF,IDIMENS*8,lenght,ierr)
        if(ierr.ne.0) stop 'SORRY: GRIB READ ERROR DETECTED'
        call GRIBEX (ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,ZSEC3,ISEC4,
     &               ZSEC4,IDIMENS,INBUFF,IDIMENS*8,iword,mode,ierr)
        if(ierr.ne.0) stop 'SORRY: GRIB CONVERSION ERROR DETECTED'
        ic=isec1(21)-1
        ij=isec1(10)
        im=isec1(11)
        id=isec1(12)
        ih=isec1(13)
        idel=isec1(16)
        jmd=ic*1000000+ij*10000+im*100+id
        hms=ih*10000
        jul=juldate(jmd,hms)
        jul=jul+dble(idel)/dble(24.0)
        call caldate(jul,jmd,hms)
c        idate(itime)=(jmd-ic*1000000)*100+hms/10000
        idate(itime)=jmd*100+hms/10000
c        if(ind.eq.1) write(*,'(a,i8.8)') 'DATE: ',idate(itime)
        if(ind.eq.1) write(*,'(a,i10.10)') 'DATE: ',idate(itime)
        if(mod(ih,3).ne.0) stop 'SORRY: ILLEGAL TIME DETECTED' 
       
        do 50 i=1,nx
          do 50 j=1,ny
            if(isec1(6).eq.142) lsp (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.143) cp  (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.146) sshf(i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.176) ssr (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.180) ewss(i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.181) nsss(i,j,itime)=zsec4(nx*(ny-j)+i)
50      continue
        if(isec1(6).eq.142) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: LSP ',isec1(6)
        endif
        if(isec1(6).eq.143) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: CP  ',isec1(6)
        endif
        if(isec1(6).eq.146) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: SSHF',isec1(6)
        endif
        if(isec1(6).eq.176) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: SSR ',isec1(6)
        endif
        if(isec1(6).eq.180) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: EWSS',isec1(6)
        endif
        if(isec1(6).eq.181) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: NSSS',isec1(6)
        endif
100   continue
*
***********************************
* P A R T  II: FG 00/06/12/18     *
* FLUXES ACCUMULATED OVER 6 HOURS *
***********************************
*
      itime=itime+1
      if(itime.gt.maxtime) then
         write(*,*) 'PLEASE NOTICE: NOT ENOUGH MEMORY TO READ'//
     &              ' ALL FLUXES'
         goto 300
      endif

      do 200 ind=1,6
        call PBGRIB(kunit1,INBUFF,IDIMENS*8,lenght,ierr)
        if(ierr.eq.-1) goto 300   ! EOF DETECTED
        if(ierr.lt.-1) stop 'SORRY: GRIB READ ERROR DETECTED'
        call GRIBEX (ISEC0,ISEC1,ISEC2,ZSEC2,ISEC3,ZSEC3,ISEC4,
     &               ZSEC4,IDIMENS,INBUFF,IDIMENS*8,iword,mode,ierr)
        if(ierr.ne.0) stop 'SORRY: GRIB CONVERSION ERROR DETECTED'
        ic=isec1(21)-1
        ij=isec1(10)
        im=isec1(11)
        id=isec1(12)
        ih=isec1(13)
        idel=isec1(16)
        jmd=ic*1000000+ij*10000+im*100+id
        hms=ih*10000
        jul=juldate(jmd,hms)
        jul=jul+dble(idel)/dble(24.0)
        call caldate(jul,jmd,hms)
c        idate(itime)=(jmd-ic*1000000)*100+hms/10000
        idate(itime)=jmd*100+hms/10000
c        if(ind.eq.1) write(*,'(a,i8.8)') 'DATE: ',idate(itime)
        if(ind.eq.1) write(*,'(a,i10.10)') 'DATE: ',idate(itime)
        if(mod(ih,3).ne.0) stop 'SORRY: ILLEGAL TIME DETECTED' 

        do 150 i=1,nx
          do 150 j=1,ny
            if(isec1(6).eq.142) lsp (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.143) cp  (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.146) sshf(i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.176) ssr (i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.180) ewss(i,j,itime)=zsec4(nx*(ny-j)+i)
            if(isec1(6).eq.181) nsss(i,j,itime)=zsec4(nx*(ny-j)+i)
150     continue
        if(isec1(6).eq.142) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: LSP ',isec1(6)
        endif
        if(isec1(6).eq.143) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: CP  ',isec1(6)
        endif
        if(isec1(6).eq.146) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: SSHF',isec1(6)
        endif
        if(isec1(6).eq.176) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: SSR ',isec1(6)
        endif
        if(isec1(6).eq.180) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: EWSS',isec1(6)
        endif
        if(isec1(6).eq.181) then
          write(*,'(6x,a,4x,i3)') 
     &      'FINNISHED: NSSS',isec1(6)
        endif
200   continue
*
      goto 10
*
* CLOSING INPUT DATA FILES
*
300   itges=itime-1
      call pbclose(kunit1,ierr) 
      call pbclose(kunit2,ierr)
*
* CHECK TIME
*
      do 400 i=2,itges
         if(idate(i-1).gt.idate(i)) 
     &   stop 'SORRY: TIMES FOR FLUX DATA NOT CORRECT'
400   continue

      return
      end 
